==> vais_speech-1.0.5.tar.gz: example/lib/record.dart <==
import 'dart:io';
import 'package:file/local.dart';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:path_provider/path_provider.dart';
import 'package:toast/toast.dart';
import 'package:vais_speech/vais.dart';
import 'package:vais_speech_example/images.dart';
import 'package:vais_speech_example/loading_view.dart';
import 'package:vais_speech_example/recording_state.dart';
import 'package:vais_speech_example/sprite_paint.dart';
import 'package:http/http.dart' as http;

const String name = "add_your_path_here.aac";
const String nameText = "add_your_path_here_text.txt";

class RecordScreen extends StatefulWidget {


  const RecordScreen({Key key,}) : super(key: key);

  @override
  _RecordScreenState createState() => _RecordScreenState();
}

class _RecordScreenState extends State<RecordScreen> with SingleTickerProviderStateMixin {
  String _text = "Welcome to streaming mode ";


  String totalOutput = "";
  Duration _duration;
  RecordingState recordingState ;
   VaisSpeechAudio vaisSpeechAudio;
   VaisSpeech vaisSpeech;
  String _path;
  String _pathText;
  TextEditingController _textTranscript ;

  AnimationController _controller;

  void _startAnimation() {
    _controller.stop();
    _controller.reset();
    _controller.repeat(
      period: Duration(seconds: 1),
    );
  }
//  static const platform = const MethodChannel('com.vais.vais_speech_example/service');
  @override
  void initState() {
    _controller = new AnimationController(
      vsync: this,
    );
    _textTranscript = new TextEditingController(text: _text);

    super.initState();
  }
  
  Future _init() async {
    setState(() {
      recordingState = RecordingState.initilized;

    });
    totalOutput = "";
    vaisSpeech = new VaisSpeech(token :'iflytek');
    vaisSpeechAudio = vaisSpeech.vaisAudio;
     var x = await getPath();
     _path = x + name;
     _pathText = x + nameText;
     print(_path);
    File file =  new LocalFileSystem().file(_pathText);

    await vaisSpeechAudio.init(_path, recordMode:  RecordMode.Streaming);
    print("Recorder initilized with ${vaisSpeechAudio.recordMode} mode !");
    vaisSpeechAudio.addListener(VaisSpeechCallback(
        onGeneratedSpeechText: (output,isFinal,audioFileName) {
          if(isFinal){
            totalOutput += ' ' + output;
            setState(() {
              _text = totalOutput;
            });
          }else{
            setState(() {
              _text  = totalOutput +' '+ output;
            });
          }


          _textTranscript.value = _textTranscript.value.copyWith(
            text:  _text,
            selection: TextSelection(baseOffset: _text.length, extentOffset: _text.length),
            composing: TextRange.empty,
          );
          file.writeAsStringSync("$_text");
//          if(isFinal){
//            _stopRecording();
//          }
        },
        onDurationChanged: (duration) {
//          print("Duration changed: $duration");
          setState(() {
            _duration = duration;
          });
        },
        onConnectionChanged: (isOnConnection) {
          if (!isOnConnection) {
            print("Connection closed");
            Toast.show("GRPC closed", context);
          }
        }
    ),singleUtterance: false);

//     final int result = await platform.invokeMethod('record');
  }

  @override
  void dispose() {
    vaisSpeechAudio?.dispose();
    _controller?.dispose();
    _stopRecording();
    super.dispose();
  }


  @override
  Widget build(BuildContext context) {
    final mContext = context;
    return Scaffold(
      appBar: AppBar(
        backgroundColor: Colors.blue,
        title: Text('Thu âm'),
      ),
      body:  Stack(
        children: <Widget>[
          Container(
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: <Widget>[
                Container(
                    height: MediaQuery.of(context).size.height / 1.6,
                    child: SingleChildScrollView(
                      child: Padding(
                          padding: EdgeInsets.only(left: 16.0, right: 16.0, top: 16.0),
                          child: Center(
                            child: new TextFormField(
                              keyboardType: TextInputType.multiline,
                              maxLines: null,

                              controller: _textTranscript,
                              enabled: false,
                              style: TextStyle(fontSize: 16,color: Colors.white),
                              decoration: new InputDecoration(
                                  labelStyle: TextStyle(fontSize: 14,color: Colors.white),
                                  border: InputBorder.none,
                                  contentPadding: new EdgeInsets.all(5)
                              ),
                            ),
//                                                  child: Text(_text,style: TextStyle(color: Colors.black ,fontSize: 16,height: 2),),
                          )
                      ),
                    ),


                    color: Colors.blue),
                Column(
                  children: <Widget>[
                    new CustomPaint(
                      painter: recordingState == RecordingState.playing ? new SpritePainter(_controller) : null,
                      child: Container(
                        margin: EdgeInsets.only(top: 32.0),
                        child: GestureDetector(
                          child: Image.asset(recording , height: 80),
                          onTap: () async {
                            switch (recordingState) {
                              case RecordingState.playing:
                                _stopRecording();
                                break;
                              default:
                                bool hasPermission = await VaisSpeechAudio.hasPermissions;
                                if (hasPermission) {
                                  _startRecording();
                                } else {
                                  Toast.show('Lack of Permission in Manifest.', context);
                                }
                            }
                          },
                        ),
                      ),
                    ),

                    Padding(
                      padding: const EdgeInsets.all(12.0),
                      child: Text(_getRecordText(recordingState),
                          style: TextStyle(
                              color: Colors.redAccent,
                              fontWeight: FontWeight.w600)),
                    ),
                  ],
                )
              ],
            ),
          ),
          recordingState == RecordingState.initilized ? LoadingView() : Container(),

        ],
      )
    );
  }

  String _getRecordText(RecordingState recordingState) {
    switch (recordingState) {
      case RecordingState.playing:
        return "Stop";
      default:
        return "";
    }
  }

  void _startRecording() async {
    await _init();
//    final int result = await platform.invokeMethod('play');
    Future.delayed(Duration(seconds: 1),() async {
      await vaisSpeechAudio.start();
      _startAnimation();
      setState(() {
        recordingState = RecordingState.playing;
      });
    });

  }


  void _stopRecording() async {
    var result = await vaisSpeechAudio.stop();
    setState(() {
      recordingState = RecordingState.stopped;
    });
//    final int result = await platform.invokeMethod('stop');

    print("Stop recording: ${result.path}");
    print("Stop recording: ${result.duration}");

    vaisSpeechAudio?.dispose();
    _controller.stop();

  }

  Future<String> getPath() async {
    Directory systemDirectory;
    if (Platform.isIOS) {
      systemDirectory = await getApplicationDocumentsDirectory();
    } else if (Platform.isAndroid){
      systemDirectory = await getExternalStorageDirectory();
    }
    await Directory(systemDirectory.path).create(recursive: true);
    return systemDirectory.path +  "/${DateTime.now().toIso8601String()}_";
  }
}

//class DisplayText extends StatelessWidget {
//  final String text;
//
//  const DisplayText({Key key, this.text = ""}) : super(key: key);
//
//  @override
//  Widget build(BuildContext context) {
//    return Container(
//      width: MediaQuery.of(context).size.width / 1.3,
//      height: MediaQuery.of(context).size.height / 3.2,
//        child: SingleChildScrollView(
//          child: Padding(
//              padding: EdgeInsets.only(left: 16.0, right: 16.0, top: 16.0),
//              child: Center(
//                child: new TextFormField(
//                  keyboardType: TextInputType.multiline,
//                  maxLines: null,
//                  controller: _textTranscript,
//                  enabled: false,
//                  style: TextStyle(fontSize: 15),
//                  decoration: new InputDecoration(
//                      labelStyle: TextStyle(fontSize: 12),
//                      border: InputBorder.none
//                  ),
//                ),
////                                                  child: Text(_text,style: TextStyle(color: Colors.black ,fontSize: 16,height: 2),),
//              )
//          ),
//        ),
//    );
//  }
//}

==> vais_speech-1.0.6.tar.gz: example/lib/record.dart <==
import 'dart:io';
import 'package:file/local.dart';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:path_provider/path_provider.dart';
import 'package:toast/toast.dart';
import 'package:vais_speech/vais.dart';
import 'package:vais_speech_example/images.dart';
import 'package:vais_speech_example/loading_view.dart';
import 'package:vais_speech_example/recording_state.dart';
import 'package:vais_speech_example/sprite_paint.dart';
import 'package:http/http.dart' as http;

const String name = "add_your_path_here.aac";
const String nameText = "add_your_path_here_text.txt";

class RecordScreen extends StatefulWidget {


  const RecordScreen({Key key,}) : super(key: key);

  @override
  _RecordScreenState createState() => _RecordScreenState();
}

class _RecordScreenState extends State<RecordScreen> with SingleTickerProviderStateMixin {
  String _text = "Welcome to streaming mode ";


  String totalOutput = "";
  Duration _duration;
  RecordingState recordingState ;
   VaisSpeechAudio vaisSpeechAudio;
   VaisSpeech vaisSpeech;
  String _path;
  String _pathText;
  TextEditingController _textTranscript ;

  AnimationController _controller;

  void _startAnimation() {
    _controller.stop();
    _controller.reset();
    _controller.repeat(
      period: Duration(seconds: 1),
    );
  }
//  static const platform = const MethodChannel('com.vais.vais_speech_example/service');
  @override
  void initState() {
    _controller = new AnimationController(
      vsync: this,
    );
    _textTranscript = new TextEditingController(text: _text);

    super.initState();
  }
  
  Future _init() async {
    setState(() {
      recordingState = RecordingState.initilized;

    });
    totalOutput = "";
    vaisSpeech = new VaisSpeech(token :'iflytek');
    vaisSpeechAudio = vaisSpeech.vaisAudio;
     var x = await getPath();
     _path = x + name;
     _pathText = x + nameText;
     print(_path);
    File file =  new LocalFileSystem().file(_pathText);

    await vaisSpeechAudio.init(_path, recordMode:  RecordMode.Streaming);
    print("Recorder initilized with ${vaisSpeechAudio.recordMode} mode !");
    vaisSpeechAudio.addListener(VaisSpeechCallback(
        onGeneratedSpeechText: (text,output,isFinal,audioFileName) {
          if(isFinal){
            totalOutput += ' ' + output;
            setState(() {
              _text = totalOutput;
            });
          }else{
            setState(() {
              _text  = totalOutput +' '+ output;
            });
          }


          _textTranscript.value = _textTranscript.value.copyWith(
            text:  _text,
            selection: TextSelection(baseOffset: _text.length, extentOffset: _text.length),
            composing: TextRange.empty,
          );
          file.writeAsStringSync("$_text");
//          if(isFinal){
//            _stopRecording();
//          }
        },
        onDurationChanged: (duration) {
//          print("Duration changed: $duration");
          setState(() {
            _duration = duration;
          });
        },
        onConnectionChanged: (isOnConnection) {
          if (!isOnConnection) {
            print("Connection closed");
            Toast.show("GRPC closed", context);
          }
        }
    ),singleUtterance: false);

//     final int result = await platform.invokeMethod('record');
  }

  @override
  void dispose() {
    vaisSpeechAudio?.dispose();
    _controller?.dispose();
    _stopRecording();
    super.dispose();
  }


  @override
  Widget build(BuildContext context) {
    final mContext = context;
    return Scaffold(
      appBar: AppBar(
        backgroundColor: Colors.blue,
        title: Text('Thu âm'),
      ),
      body:  Stack(
        children: <Widget>[
          Container(
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: <Widget>[
                Container(
                    height: MediaQuery.of(context).size.height / 1.6,
                    child: SingleChildScrollView(
                      child: Padding(
                          padding: EdgeInsets.only(left: 16.0, right: 16.0, top: 16.0),
                          child: Center(
                            child: new TextFormField(
                              keyboardType: TextInputType.multiline,
                              maxLines: null,

                              controller: _textTranscript,
                              enabled: false,
                              style: TextStyle(fontSize: 16,color: Colors.white),
                              decoration: new InputDecoration(
                                  labelStyle: TextStyle(fontSize: 14,color: Colors.white),
                                  border: InputBorder.none,
                                  contentPadding: new EdgeInsets.all(5)
                              ),
                            ),
//                                                  child: Text(_text,style: TextStyle(color: Colors.black ,fontSize: 16,height: 2),),
                          )
                      ),
                    ),


                    color: Colors.blue),
                Column(
                  children: <Widget>[
                    new CustomPaint(
                      painter: recordingState == RecordingState.playing ? new SpritePainter(_controller) : null,
                      child: Container(
                        margin: EdgeInsets.only(top: 32.0),
                        child: GestureDetector(
                          child: Image.asset(recording , height: 80),
                          onTap: () async {
                            switch (recordingState) {
                              case RecordingState.playing:
                                _stopRecording();
                                break;
                              default:
                                bool hasPermission = await VaisSpeechAudio.hasPermissions;
                                if (hasPermission) {
                                  _startRecording();
                                } else {
                                  Toast.show('Lack of Permission in Manifest.', context);
                                }
                            }
                          },
                        ),
                      ),
                    ),

                    Padding(
                      padding: const EdgeInsets.all(12.0),
                      child: Text(_getRecordText(recordingState),
                          style: TextStyle(
                              color: Colors.redAccent,
                              fontWeight: FontWeight.w600)),
                    ),
                  ],
                )
              ],
            ),
          ),
          recordingState == RecordingState.initilized ? LoadingView() : Container(),

        ],
      )
    );
  }

  String _getRecordText(RecordingState recordingState) {
    switch (recordingState) {
      case RecordingState.playing:
        return "Stop";
      default:
        return "";
    }
  }

  void _startRecording() async {
    await _init();
//    final int result = await platform.invokeMethod('play');
    Future.delayed(Duration(seconds: 1),() async {
      await vaisSpeechAudio.start();
      _startAnimation();
      setState(() {
        recordingState = RecordingState.playing;
      });
    });

  }


  void _stopRecording() async {
    var result = await vaisSpeechAudio.stop();
    setState(() {
      recordingState = RecordingState.stopped;
    });
//    final int result = await platform.invokeMethod('stop');

    print("Stop recording: ${result.path}");
    print("Stop recording: ${result.duration}");

    vaisSpeechAudio?.dispose();
    _controller.stop();

  }

  Future<String> getPath() async {
    Directory systemDirectory;
    if (Platform.isIOS) {
      systemDirectory = await getApplicationDocumentsDirectory();
    } else if (Platform.isAndroid){
      systemDirectory = await getExternalStorageDirectory();
    }
    await Directory(systemDirectory.path).create(recursive: true);
    return systemDirectory.path +  "/${DateTime.now().toIso8601String()}_";
  }
}

//class DisplayText extends StatelessWidget {
//  final String text;
//
//  const DisplayText({Key key, this.text = ""}) : super(key: key);
//
//  @override
//  Widget build(BuildContext context) {
//    return Container(
//      width: MediaQuery.of(context).size.width / 1.3,
//      height: MediaQuery.of(context).size.height / 3.2,
//        child: SingleChildScrollView(
//          child: Padding(
//              padding: EdgeInsets.only(left: 16.0, right: 16.0, top: 16.0),
//              child: Center(
//                child: new TextFormField(
//                  keyboardType: TextInputType.multiline,
//                  maxLines: null,
//                  controller: _textTranscript,
//                  enabled: false,
//                  style: TextStyle(fontSize: 15),
//                  decoration: new InputDecoration(
//                      labelStyle: TextStyle(fontSize: 12),
//                      border: InputBorder.none
//                  ),
//                ),
////                                                  child: Text(_text,style: TextStyle(color: Colors.black ,fontSize: 16,height: 2),),
//              )
//          ),
//        ),
//    );
//  }
//}
